﻿using System;
using System.Drawing;
using Telerik.WinControls;
using Telerik.WinControls.UI;

namespace PasswordStrenghtIndicators
{
    public partial class Form1 : RadForm
    {
        public Form1()
        {
            InitializeComponent();

            this.radProgressBar1.ProgressBarElement.IndicatorElement1.GradientStyle = GradientStyles.Solid;
            this.radProgressBar1.ProgressBarElement.IndicatorElement1.BackColor = Color.Red;
        }

        #region ProgressBarIndicator

        private void radTextBox1_TextChanged(object sender, EventArgs e)
        {
            int strength = this.CalculatePasswordStrength(this.radTextBox1.Text);

            if (strength > this.radProgressBar1.Maximum)
            {
                this.radProgressBar1.Value1 = this.radProgressBar1.Maximum;
            }
            else
            {
                this.radProgressBar1.Value1 = strength;
            }
        }
        
        private void radProgressBar1_ValueChanged(object sender, ProgressBarEventArgs e)
        {
            if (radProgressBar1.Value1 <= 25)
            {
                this.radProgressBar1.ProgressBarElement.IndicatorElement1.BackColor = Color.Red;
                this.radProgressBar1.Text = "Very Weak";
            }
            else if (radProgressBar1.Value1 <= 50)
            {
                this.radProgressBar1.ProgressBarElement.IndicatorElement1.BackColor = Color.Orange;
                this.radProgressBar1.Text = "Weak";
            }
            else if (radProgressBar1.Value1 <= 75)
            {
                this.radProgressBar1.ProgressBarElement.IndicatorElement1.BackColor = Color.Yellow;
                this.radProgressBar1.Text = "Fair";
            }
            else
            {
                this.radProgressBar1.ProgressBarElement.IndicatorElement1.BackColor = Color.LightGreen;
                this.radProgressBar1.Text = "Strong";
            }
        }

        #endregion

        #region LabelIndicator

        private void radTextBox2_TextChanged(object sender, EventArgs e)
        {
            int strength = this.CalculatePasswordStrength(this.radTextBox2.Text);

            if (strength <= 25)
            {
                this.radLabel1.BackColor = Color.Red;
                this.radLabel1.Text = "Very Weak";
            }
            else if (strength <= 50)
            {
                this.radLabel1.BackColor = Color.Orange;
                this.radLabel1.Text = "Weak";
            }
            else if (strength <= 75)
            {
                this.radLabel1.BackColor = Color.Yellow;
                this.radLabel1.Text = "Fair";
            }
            else
            {
                this.radLabel1.BackColor = Color.LightGreen;
                this.radLabel1.Text = "Strong";
            }
        }

        #endregion

        private int CalculatePasswordStrength(string password)
        {
            int strength = password.Length;

            bool hasDigit = false;
            int digitCount = 0;
            bool hasLetter = false;
            int letterCount = 0;
            bool hasPunctuation = false;
            int punctuationCount = 0;
            bool hasSymbol = false;
            int symbolCount = 0;

            for (int i = 0; i < password.Length; i++)
            {
                char c = password[i];

                if (Char.IsDigit(c))
                {
                    if (!hasDigit)
                    {
                        strength += 6;
                        hasDigit = true;
                    }
                    else
                    {
                        if (digitCount <= 3)
                        {
                            strength += 3;
                            digitCount++;
                        }
                    }
                }

                if (Char.IsLetter(c))
                {
                    if (!hasLetter)
                    {
                        strength += 6;
                        hasLetter = true;
                    }
                    else
                    {
                        if (letterCount <= 3)
                        {
                            strength += 1;
                            letterCount++;
                        }
                    }
                }

                if (Char.IsPunctuation(c))
                {
                    if (!hasPunctuation)
                    {
                        strength += 8;
                        hasPunctuation = true;
                    }
                    else
                    {
                        if (punctuationCount <= 3)
                        {
                            strength += 4;
                            punctuationCount++;
                        }
                    }
                }

                if (Char.IsSymbol(c))
                {
                    if (!hasSymbol)
                    {
                        strength += 10;
                        hasSymbol = true;
                    }
                    else
                    {
                        if (symbolCount <= 3)
                        {
                            strength += 5;
                            symbolCount++;
                        }
                    }
                }
            }

            return strength;
        }

    }
}
